@@ -1,3 +1,3 @@
-from .iri import IRI
+from .iri import IRI, IRI_etemp_only, STEC
 from .data_update import update
 from .read_iri_data import readapf107
\ No newline at end of file
